{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :members:
   :undoc-members:
   :special-members:
   :private-members:
   :inherited-members:
   :show-inheritance:

   .. autoclasstoc:: 

